@@ -135,6 +135,13 @@ static const rpi_hw_t rpi_hw_info[] = {
         .videocore_base = VIDEOCORE_BASE_RPI2,
         .desc = "Pi 4 Model B - 4GB v1.4"
     },
+    {
+        .hwver = 0xa03115,
+        .type = RPI_HWVER_TYPE_PI4,
+        .periph_base = PERIPH_BASE_RPI4,
+        .videocore_base = VIDEOCORE_BASE_RPI2,
+        .desc = "Pi 4 Model B - 1GB v1.5"
+    },
     {
         .hwver = 0xb03115,
         .type = RPI_HWVER_TYPE_PI4,
@@ -142,6 +149,20 @@ static const rpi_hw_t rpi_hw_info[] = {
         .videocore_base = VIDEOCORE_BASE_RPI2,
         .desc = "Pi 4 Model B - 2GB v1.5"
     },
+    {
+        .hwver = 0xc03115,
+        .type = RPI_HWVER_TYPE_PI4,
+        .periph_base = PERIPH_BASE_RPI4,
+        .videocore_base = VIDEOCORE_BASE_RPI2,
+        .desc = "Pi 4 Model B - 4GB v1.5"
+    },
+    { 
+        .hwver = 0xd03115,
+        .type = RPI_HWVER_TYPE_PI4,
+        .periph_base = PERIPH_BASE_RPI4,
+        .videocore_base = VIDEOCORE_BASE_RPI2,
+        .desc = "Pi 4 Model B - 8GB v1.5"
+    },
     //
     // Compute Module 4
     //
@@ -436,7 +457,7 @@ static const rpi_hw_t rpi_hw_info[] = {
         .desc = "Pi 3",
     },
     {
-	.hwver  = 0xa02083,
+        .hwver  = 0xa02083,
         .type = RPI_HWVER_TYPE_PI2,
         .periph_base = PERIPH_BASE_RPI2,
         .videocore_base = VIDEOCORE_BASE_RPI2,
